@@ -9,7 +9,7 @@ function(x, top = min(20, dim(x$importance)[1]), digits = max(3, getOption("digi
      cat("  variables are sorted by average importance across the classes\n")
      
    if(top < dim(x$importance)[1]) 
-      cat("  only", top, "most important variables shown (out of", dim(x$importance)[1], ")\n\n")
+      cat("  only ", top, " most important variables shown (out of ", dim(x$importance)[1], ")\n\n", sep = "")
     
    if(dim(printObj)[2] == 2)
    {
